@@ -1,3 +1,4 @@
+import copy
 import importlib.machinery
 import inspect
 import logging
@@ -20,7 +21,7 @@ import pop.scanner
 import pop.verify
 
 try:
-    import pytest_pop.mods
+    import pytest_pop.mods  # noqa
 
     HAS_TESTING_LIBS = True
 except ImportError:
@@ -62,23 +63,60 @@ class Hub:
             pypaths.append("pytest_pop.mods")
         self._subs["pop"] = Sub(self, "pop", pypath=pypaths)
         self._reverse_sub = None
-        self._iter_subs = sorted(self._subs.keys())
         self._iter_ind = 0
         # Set up the conf OPT structure so it is always available
         self.OPT = {}
 
+    @property
+    def _iter_subs(self):
+        return sorted(self._subs.keys())
+
     def __getstate__(self) -> Dict:
-        return dict(_subs=self._subs)
+        return dict(
+            reverse_sub=self._reverse_sub,
+            subs=self._subs,
+            OPT=copy.copy(self.OPT),
+        )
 
     def __setstate__(self, state: Dict):
-        self.__dict__.update(state)
+        self.__init__()
+        subs = state["subs"]
+        opt = state["OPT"]
+        reverse_sub = state["reverse_sub"]
+
+        self.OPT = self.pop.data.imap(opt)
+        self._restore_subs(subs, self)
+        if reverse_sub:
+            self.pop.sub.dynamic(
+                sub=self,
+                resolver=reverse_sub._resolver,
+                context=reverse_sub._context,
+                **reverse_sub._restoreable_state,
+            )
+
+    def _restore_subs(self, subs: Dict[str, "Sub"], root):
+        """
+        Recursively restore all pickled subs that were added to this hub.
+        Make sure they are prepared properly with inits/virtuals/loadedmods
+        """
+        for name, sub in subs.items():
+            if sub._reverse_sub:
+                self.pop.sub.dynamic(
+                    resolver=sub._reverse_sub._resolver,
+                    context=sub._reverse_sub._context,
+                    sub=root,
+                    **sub._reverse_sub._restoreable_state,
+                )
+            else:
+                self.pop.sub.add(sub=root, load_all=True, **sub._restoreable_state)
+            self._restore_subs(sub._subs, root[name])
 
     def __iter__(self) -> Iterator["Sub"]:
-        def iter(subs: Dict[str, Sub]):
-            for sub in sorted(subs.keys()):
+        def iterator(subs: Dict[str, Sub]):
+            for sub in self._iter_subs:
                 yield subs[sub]
 
-        return iter(self._subs)
+        return iterator(self._subs)
 
     def _resolve_this(self, levels: int) -> "Hub":
         """
@@ -114,7 +152,6 @@ class Hub:
             # Remove the subsystem
             self._subs.pop(subname)
             # reset the iterator
-            self._iter_subs = sorted(self._subs.keys())
             self._iter_ind = 0
             return True
         return False
@@ -309,26 +346,36 @@ class Sub:
 
     def __getstate__(self):
         return dict(
-            _hub=self._hub,
-            _subname=self._subname,
-            _pypath=self._pypath,
-            _static=self._static,
-            _contracts_pypath=self._contracts_pypath,
-            _contracts_static=self._contracts_static,
-            _default_contracts=self._default_contracts,
-            _virtual=self._virtual,
-            _omit_start=self._omit_start,
-            _omit_end=self._omit_end,
-            _omit_func=self._omit_func,
-            _omit_class=self._omit_class,
-            _omit_vars=self._omit_vars,
-            _mod_basename=self._mod_basename,
-            _stop_on_failures=self._stop_on_failures,
+            pypath=self._pypath,
+            subname=self._subname,
+            static=self._static,
+            contracts_pypath=self._contracts_pypath,
+            contracts_static=self._contracts_static,
+            default_contracts=self._default_contracts,
+            virtual=self._virtual,
+            dyne_name=self._dyne_name,
+            omit_start=self._omit_start,
+            omit_end=self._omit_end,
+            omit_func=self._omit_func,
+            omit_class=self._omit_class,
+            omit_vars=self._omit_vars,
+            mod_basename=self._mod_basename,
+            stop_on_failures=self._stop_on_failures,
+            init=self._process_init,
+            recursive_contracts_static=self._recursive_contracts_static,
+            default_recursive_contracts=self._default_recursive_contracts,
+            _subs=self._subs,
+            _reverse_sub=self._reverse_sub,
         )
 
     def __setstate__(self, state: Dict):
-        self.__dict__.update(state)
-        self._prepare()
+        """
+        Only a hub can truly restore a sub because of their interdependency
+        """
+        self._subs = state.pop("_subs")
+        self._reverse_sub = state.pop("_reverse_sub")
+        # This will have all the arguments needed to recreate the Sub with pop.sub.add
+        self._restoreable_state = state
 
     def __getattr__(self, item: str):
         """
@@ -410,7 +457,7 @@ class Sub:
             error = "{0[msg]}: {0[verror]}".format(mod())
             if skip_full_stop is False and self._stop_on_failures is True:
                 raise pop.exc.PopError(error)
-            log.info(error)
+            log.log(level=5, msg=error)
             return False
         error = "{0[msg]}: {0[exception]!r}".format(mod())
         if mod.traceback:
@@ -596,6 +643,30 @@ class ReverseSub(Sub):
         # Imitate the name attribute like a callable should
         self.__name__ = self._subname
 
+    def __getstate__(self):
+        sub = Sub.__getstate__(self)
+        # These are all the args required to recreate the ReverseSub with hub.pop.sub.dynamic()
+        sub["resolver"] = self._resolver
+        sub["context"] = self._context
+        # These are for when the reverse sub is wrapped directly
+        sub["refs"] = self._refs
+        sub["hub"] = self._hub
+        return sub
+
+    def __setstate__(self, state: Dict):
+        """
+        Sometimes a reverse sub will be called by proxy and can be restored by a hub.
+        Sometimes it is called directly and the ReverseSub needs to have everything inside it.
+        """
+        self.__init__(
+            hub=state.pop("hub"),
+            subname=state["subname"],
+            resolver=state.pop("resolver"),
+            context=state.pop("context"),
+            refs=state.pop("refs"),
+        )
+        Sub.__setstate__(self, state)
+
     def __getattr__(self, item: str):
         """
         Build a reference based on the namespace attrs until a reverse sub is called
