@@ -7,6 +7,11 @@ from typing import Dict
 from typing import List
 
 
+def __virtual__(hub):
+    hub.pop.sub.add("pop_conf.conf")
+    return hasattr(hub.conf, "integrate"), "pop-conf is not installed"
+
+
 def integrate(
     hub: "pop.hub.Hub",
     imports: List[str] or str,
@@ -20,7 +25,6 @@ def integrate(
     Load the conf sub and run the integrate sequence.
     """
     warnings.warn("Use `hub.pop.config.load()` instead", DeprecationWarning)
-    hub.pop.sub.add("pop_conf.conf")
     hub.conf.integrate.load(
         imports, override, cli=cli, roots=roots, loader=loader, logs=logs
     )
