@@ -2,12 +2,9 @@
 Control and add subsystems to the running daemon hub
 """
 import os
-from collections.abc import Mapping
 from typing import Any
 from typing import Callable
-from typing import Dict
 from typing import Generator
-from typing import Iterator
 from typing import List
 from typing import Tuple
 
@@ -98,7 +95,6 @@ def add(
     )
     # init the sub (init.py:__init__) after it can be referenced on the hub!
     root._subs[subname]._sub_init()
-    root._iter_subs = sorted(root._subs.keys())
     if load_all:
         root._subs[subname]._load_all()
     for alias in root._subs[subname]._alias:
@@ -278,12 +274,12 @@ def dynamic(
     :param kwargs: kwargs to pass directly to hub.pop.sub.add
     """
     subname = kwargs.pop("subname", None)
-    if "pypath" in kwargs and not subname:
+    if kwargs.get("pypath") and not subname:
         pypath = pop.hub.ex_path(kwargs["pypath"])
         subname = pypath[0].split(".")[-1]
-    elif "static" in kwargs:
+    elif kwargs.get("static"):
         subname = os.path.basename(kwargs["static"])
-    if "dyne_name" in kwargs and not subname:
+    if kwargs.get("dyne_name") and not subname:
         subname = kwargs["dyne_name"]
 
     root = kwargs.pop("sub", hub)
